@@ -23,7 +23,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_rawcode_imengine.cpp,v 1.7.2.6 2006/01/18 05:44:52 suzhe Exp $
+ * $Id: scim_rawcode_imengine.cpp,v 1.7.2.7 2007/04/10 07:47:18 suzhe Exp $
  *
  */
 
@@ -50,13 +50,16 @@ using namespace scim;
 
 static Pointer <RawCodeFactory> __rawcode_factory;
 
-static String __rawcode_locales ("zh_CN.GB18030,zh_CN.GBK,zh_CN.GB2312,zh_TW,zh_TW.EUC-TW,zh_HK,ja_JP,ja_JP.sjis,ko_KR,en_US.UTF-8");
+static String __rawcode_locales;
 
 static std::vector<String> __rawcode_encodings;
 
 extern "C" {
     void scim_module_init (void)
     {
+        __rawcode_locales = String (
+            "zh_CN.GB18030,zh_CN.GBK,zh_CN.GB2312,zh_TW,zh_TW.EUC-TW,zh_HK,"
+            "ja_JP,ja_JP.sjis,ko_KR,en_US.UTF-8");
     }
 
     void scim_module_exit (void)
