@@ -23,7 +23,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_imengine_setup.cpp,v 1.9 2005/08/15 06:33:26 suzhe Exp $
+ * $Id: scim_imengine_setup.cpp,v 1.9.2.2 2006/09/24 16:00:51 suzhe Exp $
  *
  */
 
@@ -306,6 +306,30 @@ create_setup_window ()
         gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow), 
                                              GTK_SHADOW_NONE);
  
+        // Create hotkey and filter button before factory list view, because
+        // factory_list_selection_changed_callback may access these two buttons.
+        __hotkey_button = gtk_button_new_with_mnemonic (_("Edit _Hotkeys"));
+        gtk_widget_show (__hotkey_button);
+        gtk_widget_set_sensitive (__hotkey_button, FALSE);
+
+        g_signal_connect ((gpointer) __hotkey_button, "clicked",
+                          G_CALLBACK (on_hotkey_button_clicked),
+                          NULL);
+
+        gtk_tooltips_set_tip (__widget_tooltips, __hotkey_button,
+                              _("Edit Hotkeys associated with the selected input method."), NULL);
+
+        __filter_button = gtk_button_new_with_mnemonic (_("Select _Filters"));
+        gtk_widget_show (__filter_button);
+        gtk_widget_set_sensitive (__filter_button, FALSE);
+
+        g_signal_connect ((gpointer) __filter_button, "clicked",
+                          G_CALLBACK (on_filter_button_clicked),
+                          NULL);
+
+        gtk_tooltips_set_tip (__widget_tooltips, __filter_button,
+                              _("Select the Filters which will be attached to this input method."), NULL);
+
         view = create_factory_list_view ();
         gtk_widget_show (view);
         gtk_container_add (GTK_CONTAINER (scrolledwindow), view);
@@ -318,30 +342,9 @@ create_setup_window ()
         gtk_widget_show (hbox);
         gtk_box_pack_start (GTK_BOX (window), hbox, FALSE, FALSE, 2);
 
-        __hotkey_button = gtk_button_new_with_mnemonic (_("Edit _Hotkeys"));
-        gtk_widget_show (__hotkey_button);
-        gtk_widget_set_sensitive (__hotkey_button, FALSE);
         gtk_box_pack_end (GTK_BOX (hbox), __hotkey_button, FALSE, FALSE, 4);
- 
-        g_signal_connect ((gpointer) __hotkey_button, "clicked",
-                          G_CALLBACK (on_hotkey_button_clicked),
-                          NULL);
-
-        gtk_tooltips_set_tip (__widget_tooltips, __hotkey_button,
-                              _("Edit Hotkeys associated with the selected input method."), NULL);
-
-        __filter_button = gtk_button_new_with_mnemonic (_("Select _Filters"));
-        gtk_widget_show (__filter_button);
-        gtk_widget_set_sensitive (__filter_button, FALSE);
         gtk_box_pack_end (GTK_BOX (hbox), __filter_button, FALSE, FALSE, 4);
  
-        g_signal_connect ((gpointer) __filter_button, "clicked",
-                          G_CALLBACK (on_filter_button_clicked),
-                          NULL);
-
-        gtk_tooltips_set_tip (__widget_tooltips, __filter_button,
-                              _("Select the Filters which will be attached to this input method."), NULL);
-
         button = gtk_button_new_with_mnemonic (_("_Expand"));
         gtk_widget_show (button);
         gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 4);
@@ -1260,6 +1263,8 @@ on_toggle_all_button_clicked (GtkButton *button, gpointer user_data)
     gtk_tree_model_foreach (GTK_TREE_MODEL (__factory_list_model),
                             factory_list_toggle_all_func,
                             user_data);
+
+    __have_changed = true;
 }
 
 static void
