@@ -23,7 +23,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_panel_agent.cpp,v 1.7 2005/06/30 10:25:18 suzhe Exp $
+ * $Id: scim_panel_agent.cpp,v 1.8.2.1 2006/01/09 14:32:18 suzhe Exp $
  *
  */
 
@@ -856,18 +856,21 @@ private:
                     current = last = false;
                     uuid.clear ();
 
-                    if (m_current_socket_client == client_id && m_current_client_context == context) {
-                        current = true;
-                        uuid = m_current_context_uuid;
-                    } else if (m_last_socket_client == client_id && m_last_client_context == context) {
-                        last = true;
-                        uuid = m_last_context_uuid;
-                    } else {
+                    // Get the context uuid from the client context registration table.
+                    {
                         ClientContextUUIDRepository::iterator it = m_client_context_uuids.find (get_helper_ic (client_id, context));
                         if (it != m_client_context_uuids.end ())
                             uuid = it->second;
                     }
 
+                    if (m_current_socket_client == client_id && m_current_client_context == context) {
+                        current = true;
+                        if (!uuid.length ()) uuid = m_current_context_uuid;
+                    } else if (m_last_socket_client == client_id && m_last_client_context == context) {
+                        last = true;
+                        if (!uuid.length ()) uuid = m_last_context_uuid;
+                    }
+
                     // Skip to the next command and continue, if it's not current or last focused.
                     if (!uuid.length ()) {
                         SCIM_DEBUG_MAIN (3) << "PanelAgent:: Couldn't find context uuid.\n";
@@ -1051,7 +1054,9 @@ private:
  
                 unlock ();
 
-                m_signal_turn_off ();
+                socket_transaction_start ();
+                socket_turn_off ();
+                socket_transaction_end ();
             }
 
             if (m_last_socket_client == client.get_id ()) {
@@ -1100,7 +1105,9 @@ private:
 
             unlock ();
 
+            socket_transaction_start ();
             m_signal_remove_helper (client.get_id ());
+            socket_transaction_end ();
         }
     }
 
@@ -1444,7 +1451,7 @@ private:
 
             SCIM_DEBUG_MAIN(5) << "Target UUID = " << target_uuid << "  Focused UUId = " << focused_uuid << "\nTarget Client = " << target_client << "\n";
 
-            if (target_uuid == focused_uuid && client_info.type == FRONTEND_CLIENT) {
+            if (client_info.type == FRONTEND_CLIENT) {
                 Socket socket_client (target_client);
                 lock ();
                 m_send_trans.clear ();
