@@ -595,7 +595,7 @@ scim_get_user_data_dir ()
 String
 scim_get_current_locale ()
 {
-    char *locale = setlocale (LC_CTYPE, 0);
+    char *locale = setlocale (LC_MESSAGES, 0);
 
     if (locale) return String (locale);
     return String ();
@@ -682,11 +682,11 @@ scim_make_dir (const String &dir)
 }
 
 struct __Language {
-    char *code;
-    char *normalized;
-    char *name;
-    char *untranslated;
-    char *locale_suffix;
+    const char *code;
+    const char *normalized;
+    const char *name;
+    const char *untranslated;
+    const char *locale_suffix;
 };
 
 static __Language __languages [] = {
@@ -717,6 +717,7 @@ static __Language __languages [] = {
     { "en_GB",    NULL, N_("English (British)"), "British English", ".iso885915" },
     { "en_IE",    NULL, N_("English (Ireland)"), "Irish English", NULL },
     { "en_US",    NULL, N_("English (American)"), "American English", ".iso885915" },
+    { "eo",       NULL, N_("Esperanto"), "Esperanto", NULL },
     { "es",    "es_ES", N_("Spanish"), "Español", NULL },
     { "es_ES",    NULL, N_("Spanish"), "Español", "@euro" },
     { "es_MX",    NULL, N_("Spanish (Mexico)"), "Español (Mexico)", NULL },
