@@ -305,6 +305,7 @@ scim_key_selection_add_key_button_callback (GtkButton        *button,
 {
     GtkTreeIter iter;
     String key;
+    String key_code;
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (keyselection->toggle_ctrl)))
         key += String ("Control+");
@@ -319,7 +320,20 @@ scim_key_selection_add_key_button_callback (GtkButton        *button,
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (keyselection->toggle_hyper)))
         key += String ("Hyper+");
 
-    key += String (gtk_entry_get_text (GTK_ENTRY (keyselection->key_code)));
+    key_code = String (gtk_entry_get_text (GTK_ENTRY (keyselection->key_code)));
+    if (!key_code.length ()){
+      // empty key code is not allowed.
+      GtkWidget *dialog;
+      dialog = gtk_message_dialog_new (NULL,
+                                       GTK_DIALOG_MODAL,
+                                       GTK_MESSAGE_ERROR,
+                                       GTK_BUTTONS_CLOSE,
+                                       _("Please enter a Key Code first."));
+      gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
+      return;
+    }
+    key += key_code;
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (keyselection->toggle_release)))
         key += String ("+KeyRelease");
